@@ -8,9 +8,9 @@ import os
 # Once those libraries have updated to rebuild their _pb2.py files,
 # this can be removed.
 os.environ["PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION"] = "python"
-os.environ["GRPC_VERBOSITY"] = "debug"
-os.environ["GRPC_TRACE"] = "all"
-os.environ["TSI_OPENSSL_ALPN_SUPPORT"] = "1"
+# os.environ["GRPC_VERBOSITY"] = "debug"
+# os.environ["GRPC_TRACE"] = "all"
+# os.environ["TSI_OPENSSL_ALPN_SUPPORT"] = "1"
 print(os.environ)
 try:
   from google.protobuf.internal import builder as _builder
