@@ -24,7 +24,7 @@ def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Di
     """ # 실행과 실험환경을 만드는 함수 """
     # exp_name 변수 vailidation
     if exp_name:
-        pattern = re.compile('[^a-zA-Z0-9._]+')
+        pattern = re.compile('[^a-zA-Z0-9._-]+')
         if pattern.findall(exp_name):
             logger.error("init() failed : exp_name은 숫자(number), 영문자(alphabet), 언더바(_), 온점(.)만 가능합니다.")
             return None
