@@ -32,6 +32,8 @@ def get_stub() -> ResourceStub:
 grpc_host : str = "127.0.0.1:19051"
 use_grpc_tls : bool = False # GPRC의 tls(ssl) 사용여부
 use_https : bool = False
+cert_path: str = None
+
 def set_grpc_host(grpc_host_: str, use_grpc_tls_=False) -> None:
     global grpc_host
     global use_grpc_tls
@@ -42,6 +44,15 @@ def get_grpc_host() -> str:
     global grpc_host
     return grpc_host
 
+def set_cert_path(cert_path_: str) -> None:
+    global cert_path
+    cert_path = cert_path_
+    http_interface.set_cert_path(cert_path_)
+
+def get_cert_path() -> str:
+    global cert_path
+    return cert_path
+
 def get_use_grpc_tls() -> bool:
     global use_grpc_tls
     return use_grpc_tls
@@ -354,15 +365,21 @@ def login(key: str) -> (bool, str):
         # grpc stub 생성
         if use_grpc_tls:
             #channel_opt = ()
+
             #channel_opt += (('grpc.ssl_target_name_override', 'lgcn.com'),)
             # with open('lgcns.crt', 'rb') as f:
             #     creds = grpc.ssl_channel_credentials(f.read())
+            if get_cert_path() is not None:
+                with open(get_cert_path(), 'rb') as f:
+                    creds = grpc.ssl_channel_credentials(f.read())
+            else:
+                creds = grpc.ssl_channel_credentials()
+
 
             #creds = grpc.ssl_channel_credentials()
-            #grpc_channel_args = (('grpc.ssl_target_name_override', 'bokchi.com'),)
-
-            creds = grpc.ssl_channel_credentials()
-            channel = grpc.secure_channel(target =grpc_url, credentials=creds)#, options=grpc_channel_args)
+            grpc_channel_args = ()
+            grpc_channel_args += (('grpc.max_receive_message_length', 100*1024*1024),)
+            channel = grpc.secure_channel(target =grpc_url, credentials=creds, options=grpc_channel_args)
         else:
             channel = grpc.insecure_channel(grpc_url)
         stub = ResourceStub(channel)
